ui

package
v0.0.0-...-0f11aa8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2026 License: AGPL-3.0 Imports: 32 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewEngine

func NewEngine(
	ctx context.Context,
	agentName string,
	providerID string,
	agentsFilePath string,
	hitl llm.HITLHandler,
	unsafeAllTools bool,
) (llm.Engine, *config.InstanceConfig, working.WorkingMemory, func(), error)

NewEngine creates an llm.Engine using the given parameters and configurations. If the agent specifies a Workflow, it natively wraps execution in a WorkflowEngine.

func NewEnrichersFromConfig

func NewEnrichersFromConfig(cfgs []config.Enricher) ([]llm.BeforeGenerateHook, error)

NewEnrichersFromConfig builds an array of BeforeGenerate hooks from raw agent configuration.

func NewMCPResolversFromConfig

func NewMCPResolversFromConfig(ctx context.Context, agentName string, mcpConfigs []config.ToolConfig) ([]llm.ToolProvider, func(), error)

NewMCPResolversFromConfig builds an array of tool resolvers from an array of MCP tool configurations. It connects to the MCP servers, initializes them, and binds resolving wrappers to them.

func NewProviderFromConfig

func NewProviderFromConfig(cfg config.InstanceConfig) (provider.Provider, error)

NewProviderFromConfig maps a generic config definition to a concrete LLM Provider constructor.

func NewResolversFromConfig

func NewResolversFromConfig(cfgs []string, deps ResolverDependencies) ([]llm.ToolProvider, *semmem.Service, error)

NewResolversFromConfig builds an array of tool resolvers from string representations. When semantic tools are requested, it creates (or reuses) a semantic service and returns it.

Types

type ResolverDependencies

type ResolverDependencies struct {
	GlobalMemory    llm.History
	SemanticService *semmem.Service // optional; reused or populated by NewResolversFromConfig
}

ResolverDependencies holds runtime state required by built-in tool resolvers.

Directories

Path Synopsis
web

Jump to