transition

package
v0.0.0-...-0f11aa8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2026 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Tool

type Tool struct {
	// contains filtered or unexported fields
}

Tool provides a dynamically instantiated tool that triggers a Context Router state change.

func New

func New(targetMode, description string) *Tool

New creates a new transition tool targeting a specific state in the Workflow.

func (*Tool) Definition

func (t *Tool) Definition() llm.ToolDefinitionPart

Definition formats the tool accurately for the LLM to understand.

func (*Tool) Execute

func (t *Tool) Execute(ctx context.Context, args map[string]interface{}) (interface{}, error)

Execute emits the TransitionSignalPart which safely trips the workflow engine interceptors.

func (*Tool) Name

func (t *Tool) Name() string

Jump to