Documentation
¶
Index ¶
- func NewMux(agentsDir string, agentName string, providerID string) *http.ServeMux
- type EngineFactory
- type Server
- type Session
- type Streamer
- type WebHITL
- type WebView
- func (v *WebView) Flush()
- func (v *WebView) OnCommand(cmd string, args []string)
- func (v *WebView) PromptHITL(req *llm.ToolRequestPart)
- func (v *WebView) RenderError(err error)
- func (v *WebView) RenderTelemetry(telemetry llm.TelemetryPart)
- func (v *WebView) RenderTextChunk(chunk string)
- func (v *WebView) RenderThinkingChunk(chunk string)
- func (v *WebView) RenderToolIntent(toolName string, args any)
- func (v *WebView) RenderToolResult(toolName string, result any, isError bool)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type EngineFactory ¶
type Streamer ¶
type Streamer interface {
Stream(ctx context.Context, inputMessage llm.Message) (<-chan llm.Message, error)
}
Streamer interface abstracts the physical Engine for testing
type WebHITL ¶
type WebHITL struct {
// contains filtered or unexported fields
}
WebHITL implements a synchronous block for human in the loop interactions over HTTP. When ApproveTool is called by the LLM, the execution is blocked via a WaitGroup/Channel until a separate HTTP request `/api/chat/approve` signals the decision.
func NewWebHITL ¶
func NewWebHITL() *WebHITL
func (*WebHITL) ApproveTool ¶
ApproveTool blocks until a decision is made via the API.
type WebView ¶
type WebView struct {
// contains filtered or unexported fields
}
WebView implements the different UI Extension features.
func (*WebView) PromptHITL ¶
func (v *WebView) PromptHITL(req *llm.ToolRequestPart)
func (*WebView) RenderError ¶
func (*WebView) RenderTelemetry ¶
func (v *WebView) RenderTelemetry(telemetry llm.TelemetryPart)
func (*WebView) RenderTextChunk ¶
func (*WebView) RenderThinkingChunk ¶
func (*WebView) RenderToolIntent ¶
Click to show internal directories.
Click to hide internal directories.